@@ -6,7 +6,7 @@ use Regexp::Grammars;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '0.007';    # VERSION
+our $VERSION = '0.008';    # VERSION
 
 # ABSTRACT: Parse DOS .bat and .cmd files
 
@@ -61,7 +61,7 @@ has 'grammar' => (
 
            <token: Token> [^\n]*
 
-           <token: LabelIdentifier> [^\n\s]*
+           <token: LabelIdentifier> [^\n\s\:]*
 
         }xmi;
     }
@@ -106,7 +106,7 @@ App::BatParser - Parse DOS .bat and .cmd files
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 DESCRIPTION
 
